// pins used
//  sd card uses SPI
//    10 cs
//    11 MOSI
//    13 CLOCK
//    12 MISO
//  moisture sensors
//    A0
//    A1
// ds1820 bus pin
//  2
const int moist1pin = 0;
const int moist2pin = 1;

// Date and time functions using a DS1307 RTC connected via I2C and Wire lib
#include "RTClib.h"

//includes for temperature dallas semi
#include <Wire.h>
#include <OneWire.h>
#include <DallasTemperature.h>



// include for sd card
#include <SPI.h>
#include <SD.h>

RTC_DS1307 rtc;

#define ONE_WIRE_BUS_PIN 2              // The pin that we are using for sensor
OneWire oneWire(ONE_WIRE_BUS_PIN);     // Setup oneWire
DallasTemperature sensors(&oneWire);   //  oneWire to Dallas Temperature.
DeviceAddress Tempaboveadd = { 0x28, 0x02, 0xD2, 0x08, 0x2E, 0x19, 0x01, 0xD1 }; //above ground sensor
DeviceAddress Temp6add = { 0x28, 0xB4, 0x96, 0x56, 0xB5, 0x01, 0x3C, 0x6F }; //6" sensor
DeviceAddress Temp12add = { 0x28, 0x54, 0x2A, 0x15, 0x2E, 0x19, 0x01, 0x70 }; //12" sensor


void setup () {
  pinMode(moist1pin, INPUT_PULLUP);
  pinMode(moist2pin, INPUT_PULLUP);

  Wire.begin();
  sensors.begin();
  //sensors.setResolution(Tempaboveadd, 9);// set the resolution to 9 bit (Can be 9 to 12 bits .. lower is faster)
  //sensors.setResolution(Temp6add, 9);// set the resolution to 9 bit (Can be 9 to 12 bits .. lower is faster)
  //sensors.setResolution(Temp12add, 9);// set the resolution to 9 bit (Can be 9 to 12 bits .. lower is faster)

  // Open serial communications and wait for port to open:
  Serial.begin(9600);
  while (!Serial) {
    ; // wait for serial port to connect. Needed for native USB port only
  }

  Serial.print("Initializing SD card...");
  if (!SD.begin(10)) {
    Serial.println("initialization failed!");
    while (1);
  }
  Serial.println("initialization done.");

#ifndef ESP8266
  while (!Serial); // wait for serial port to connect. Needed for native USB
#endif

  if (! rtc.begin()) {
    Serial.println("Couldn't find RTC");
    Serial.flush();
    abort();
  }

  if (! rtc.isrunning()) {
    Serial.println("RTC is NOT running, let's set the time!");
    // When time needs to be set on a new device, or after a power loss, the
    // following line sets the RTC to the date & time this sketch was compiled
    rtc.adjust(DateTime(F(__DATE__), F(__TIME__)));
    // This line sets the RTC with an explicit date & time, for example to set
    // January 21, 2014 at 3am you would call:
    // rtc.adjust(DateTime(2014, 1, 21, 3, 0, 0));
  }

  // When time needs to be re-set on a previously configured device, the
  // following line sets the RTC to the date & time this sketch was compiled
  // rtc.adjust(DateTime(F(__DATE__), F(__TIME__)));
  // This line sets the RTC with an explicit date & time, for example to set
  // January 21, 2014 at 3am you would call:
  // rtc.adjust(DateTime(2014, 1, 21, 3, 0, 0));
}

void loop () {
  DateTime now = rtc.now();
  File dataFile = SD.open("data2.txt", FILE_WRITE);

  if (dataFile) {
    // put sensor read data here
    int moist1 = analogRead(moist1pin);
    int moist2 = analogRead(moist2pin);

    moist1 = map(moist1, 0, 1023, 0, 100);
    moist2 = map(moist2, 0, 1023, 0, 100);


    // put sensor write to file here
    // string format Month/Day/Year, hour:minute, Moisture6", Moisture12", Tempair, Temp6", Temp12",
    String DateTimeString = String(now.month(), DEC) + " " + String(now.day(), DEC) + " " + String(now.year(), DEC) + " " + String(now.hour(), DEC)+" "+ String(now.minute(), DEC);

    //DateTimeString = DateTimeString + String(now.hour(), DEC)+ " ";

    //DateTimeString = DateTimeString + String(now.minute(), DEC);
    //DateTimeString = DateTimeString + String(now.hour(), DEC) + ":" + String(now.minute(), DEC);

    dataFile.print(DateTimeString);
    dataFile.print(" ");
    dataFile.print(moist1);
    dataFile.print(" ");
    dataFile.print(moist2);
    dataFile.print(" ");
    sensors.requestTemperatures();
    float Tempabove = sensors.getTempF(Tempaboveadd);
    dataFile.print(Tempabove, 1);
    dataFile.print(" ");
    float Temp6 = sensors.getTempF(Temp6add);
    dataFile.print(Temp6, 1);
    dataFile.print(" ");
    float Temp12 = sensors.getTempF(Temp12add);
    dataFile.print(Temp12, 1);
    dataFile.println(" ");
    dataFile.close();

    Serial.print(DateTimeString);
    Serial.print(" ");
    Serial.print(moist1);
    Serial.print(" ");
    Serial.print(moist2);
    Serial.print(" ");
    Serial.print(Tempabove, 1);
    Serial.print(" ");
    Serial.print(Temp6, 1);
    Serial.print(" ");
    Serial.print(Temp12, 1);
    Serial.println(" "); 

  } else {
    Serial.println("error opening file");
  };

  delay(1000);

}
